@@ -942,7 +942,7 @@ class Update(MethodsInterface):
         self.set_need_update(False)
         return True
 
-    def _startEmerging(self, emerge):
+    def _startEmerging(self, emerge, start_msg=None):
         """
         Настроить и выполнить emerge
         """
@@ -953,6 +953,8 @@ class Update(MethodsInterface):
                     self.update_map["{CATEGORY}/{PF}".format(**pkg)] = \
                         rv.partition(":")[0]
         emerge.command.send("yes\n")
+        if start_msg is not None and isinstance(start_msg, str):
+            self.startTask(start_msg)
         emerge.emerging.add_observer(self._printEmergePackage)
         emerge.installing.add_observer(self._printInstallPackage)
         emerge.uninstalling.add_observer(self._printUninstallPackage)
@@ -1040,7 +1042,7 @@ class Update(MethodsInterface):
                 self._display_install_package(emerge, emergelike=True)
                 self._display_error(emerge.prepare_error)
                 raise
-            self._startEmerging(emerge)
+            self._startEmerging(emerge, _("Fetching..."))
         return True
 
     def depclean(self):
